@@ -2,6 +2,11 @@
 from __future__ import annotations
 import importlib
 
+from ._deploy import cli as deploy
+from ._service import cli as service
+from ._migrate import cli as migrate
+from ._server_map import cli as server_map
+
 __all__ = ["deploy", "service", "migrate", "server_map"]
 
 
