@@ -9,16 +9,17 @@ import string
 from subprocess import run
 import sys
 from urllib.parse import urlparse
-from tempfile import TemporaryDirectory, mkdtemp
+from tempfile import TemporaryDirectory
 from typing import Any
 
 from numpy import sign
-import toml
+import tomlkit
 import yaml
 
 from .utils import (
     asset_dir,
     config_dir,
+    load_config,
     get_passwd,
     get_email_credentials,
     logger,
@@ -55,7 +56,6 @@ class DeployFactory:
         steps: list[str] | None = None,
         config_file: Path | str | None = None,
     ) -> None:
-
         self._config_keys: list[str] = []
         self.master_pass: str = ""
         self.email_password: str = ""
@@ -70,6 +70,7 @@ class DeployFactory:
         self._cfg_tmpl = self.aux_dir / "evaluation_system.conf.tmpl"
         self.cfg = self._read_cfg()
         self.project_name = self.cfg.pop("project_name", None)
+        self.playbooks: dict[str, Path | None] = {}
         if not self.project_name:
             raise ValueError("You must set a project name")
 
@@ -104,6 +105,8 @@ class DeployFactory:
         """Prepare the vault."""
         self._config_keys.append("vault")
         self.cfg["vault"] = self.cfg["db"].copy()
+        self.cfg["vault"]["config"].setdefault("ansible_become_user", "root")
+        self.playbooks["vault"] = self.cfg["db"]["config"].get("vault_playbook")
         if not self.master_pass:
             self.master_pass = get_passwd()
         self.cfg["vault"]["config"]["root_passwd"] = self.master_pass
@@ -116,6 +119,7 @@ class DeployFactory:
     def _prep_db(self) -> None:
         """prepare the mariadb service."""
         self._config_keys.append("db")
+        self.cfg["db"]["config"].setdefault("ansible_become_user", "root")
         if not self.master_pass:
             self.master_pass = get_passwd()
         host = self.cfg["db"]["hosts"]
@@ -131,12 +135,15 @@ class DeployFactory:
         self.cfg["db"]["config"]["email"] = self.cfg["web"]["config"].get(
             "contacts", ""
         )
+        self.playbooks["db"] = self.cfg["db"]["config"].get("db_playbook")
         self._prep_vault()
 
     def _prep_solr(self) -> None:
         """prepare the apache solr service."""
         self._config_keys.append("solr")
+        self.cfg["solr"]["config"].setdefault("ansible_become_user", "root")
         self.cfg["solr"]["config"].pop("core", None)
+        self.playbooks["solr"] = self.cfg["solr"]["config"].get("solr_playbook")
         for key, default in dict(mem="4g", port=8983).items():
             self.cfg["solr"]["config"][key] = (
                 self.cfg["solr"]["config"].get(key) or default
@@ -148,6 +155,8 @@ class DeployFactory:
     def _prep_core(self) -> None:
         """prepare the core deployment."""
         self._config_keys.append("core")
+        self.cfg["core"]["config"].setdefault("ansible_become_user", "")
+        self.playbooks["core"] = self.cfg["core"]["config"].get("core_playbook")
         self.cfg["core"]["config"]["admins"] = (
             self.cfg["core"]["config"].get("admins") or getuser()
         )
@@ -184,6 +193,8 @@ class DeployFactory:
     def _prep_web(self) -> None:
         """prepare the web deployment."""
         self._config_keys.append("web")
+        self.playbooks["web"] = self.cfg["web"]["config"].get("web_playbook")
+        self.cfg["web"]["config"].setdefault("ansible_become_user", "root")
         self._prep_core()
         admin = self.cfg["core"]["config"]["admins"]
         if not isinstance(admin, str):
@@ -192,10 +203,12 @@ class DeployFactory:
             self.cfg["web"]["config"]["admin"] = admin
         _webserver_items = {}
         try:
-            _webserver_items = {
-                k.replace("web_", "").upper(): v
-                for (k, v) in self.cfg["web"]["config"].items()
-            }
+            for k, v in self.cfg["web"]["config"].items():
+                key = k.replace("web_", "").upper()
+                if key not in ("LDAP_USER_PW", "LDAP_USER_DN"):
+                    _webserver_items[key] = v
+                else:
+                    self.cfg["web"]["config"].setdefault(k, "")
         except KeyError as error:
             raise KeyError(
                 "No web config section given, please configure the web.config"
@@ -243,7 +256,7 @@ class DeployFactory:
         except AttributeError:
             pass
         with self.web_conf_file.open("w") as f_obj:
-            toml.dump(_webserver_items, f_obj)
+            tomlkit.dump(_webserver_items, f_obj)
         for key in ("core", "web"):
             self.cfg[key]["config"]["config_toml_file"] = str(self.web_conf_file)
         if not self.master_pass:
@@ -282,8 +295,7 @@ class DeployFactory:
 
     def _read_cfg(self) -> dict[str, Any]:
         try:
-            with self._inv_tmpl.open() as f_obj:
-                return dict(toml.load(f_obj))
+            return dict(load_config(self._inv_tmpl))
         except FileNotFoundError as error:
             raise FileNotFoundError(f"No such file {self._inv_tmpl}") from error
 
@@ -304,6 +316,7 @@ class DeployFactory:
         return [
             "admins",
             "conda_exec_path",
+            "ansible_become_user",
         ]
 
     def _get_files_copy(self, key) -> Path | None:
@@ -377,7 +390,7 @@ class DeployFactory:
             config[step]["hosts"] = self.cfg[step]["hosts"]
             config[step]["vars"] = {}
             for key, value in self.cfg[step]["config"].items():
-                if key in ("root_passwd", "wipe"):
+                if key in ("root_passwd",):
                     new_key = key
                 else:
                     new_key = f"{step}_{key}"
@@ -389,7 +402,6 @@ class DeployFactory:
 
     @property
     def _playbook_file(self) -> Path:
-
         return Path(self._td.name) / "ansible-playbook.yml"
 
     @property
@@ -423,8 +435,11 @@ class DeployFactory:
         playbook = []
         for step in self.steps:
             getattr(self, f"_prep_{step}")()
-            playbook_file = self.playbook_dir / f"{step}-server-playbook.yml"
-            with playbook_file.open() as f_obj:
+            playbook_file = (
+                self.playbooks.get(step)
+                or self.playbook_dir / f"{step}-server-playbook.yml"
+            )
+            with Path(playbook_file).open() as f_obj:
                 playbook += yaml.safe_load(f_obj)
         with self._playbook_file.open("w") as f_obj:
             yaml.dump(playbook, f_obj)
